==> opensaml-saml-impl-3.4.3-sources.jar: org/opensaml/saml/ext/saml2mdattr/impl/EntityAttributesUnmarshaller.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.saml.ext.saml2mdattr.impl;

import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.UnmarshallingException;
import org.opensaml.saml.common.AbstractSAMLObjectUnmarshaller;
import org.opensaml.saml.ext.saml2mdattr.EntityAttributes;
import org.opensaml.saml.saml2.core.Assertion;
import org.opensaml.saml.saml2.core.Attribute;

/** A thread-safe Unmarshaller for {@link org.opensaml.saml.ext.saml2mdattr.EntityAttributes}. */
public class EntityAttributesUnmarshaller extends AbstractSAMLObjectUnmarshaller {

    /** {@inheritDoc} */
    protected void processChildElement(final XMLObject parentObject, final XMLObject childObject)
            throws UnmarshallingException {
        final EntityAttributes entityAttrs = (EntityAttributes) parentObject;

        if (childObject instanceof Attribute) {
            entityAttrs.getAttributes().add((Attribute) childObject);
        } else if (childObject instanceof Assertion) {
            entityAttrs.getAssertions().add((Assertion) childObject);
        } else {
            super.processChildElement(parentObject, childObject);
        }
    }
}

==> opensaml-saml-impl-5.1.2-sources.jar: org/opensaml/saml/ext/saml2mdattr/impl/EntityAttributesUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.saml.ext.saml2mdattr.impl;

import javax.annotation.Nonnull;

import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.UnmarshallingException;
import org.opensaml.saml.common.AbstractSAMLObjectUnmarshaller;
import org.opensaml.saml.ext.saml2mdattr.EntityAttributes;
import org.opensaml.saml.saml2.core.Assertion;
import org.opensaml.saml.saml2.core.Attribute;

/** A thread-safe Unmarshaller for {@link EntityAttributes}. */
public class EntityAttributesUnmarshaller extends AbstractSAMLObjectUnmarshaller {

    /** {@inheritDoc} */
    @Override
    protected void processChildElement(@Nonnull final XMLObject parentObject, @Nonnull final XMLObject childObject)
            throws UnmarshallingException {
        final EntityAttributes entityAttrs = (EntityAttributes) parentObject;

        if (childObject instanceof Attribute) {
            entityAttrs.getAttributes().add((Attribute) childObject);
        } else if (childObject instanceof Assertion) {
            entityAttrs.getAssertions().add((Assertion) childObject);
        } else {
            super.processChildElement(parentObject, childObject);
        }
    }

}
